#!/usr/bin/env node
const program = require('commander');

const { packFiles } = require('../lib/pack');
const { APP_ID, PACK_INCLUDE, PACK_IGNORE } = require('../lib/constants');
const { fatal } = require('../lib/logger');

/**
 * Help
 */
program
  .name(
    `
$ marmot pack`,
  )
  .usage('')
  .on('--help', function() {
    console.log(`
Pack the content from "./dist" folder into "./._temp/{APP_ID}.tar", where APP_ID is an environmental variable.
`);
  });

/**
 * Parse
 */
program.parse(process.argv);

/**
 * entry
 * 1. check environmental variables
 * 2. invoke packFiles
 */
async function entry() {
  try {
    // use APP_ID from environmental variables
    const config = { id: APP_ID };

    if (PACK_INCLUDE) {
      config.include = PACK_INCLUDE;
    }
    if (PACK_IGNORE) {
      config.ignore = PACK_IGNORE;
    }

    if (!config.id) {
      fatal('Missing environmental variable APP_ID');
    }
    await packFiles(config);
  } catch (e) {
    fatal('Pack offline-package failed.', e);
  }
}

entry();
