#!/usr/bin/env node

const { existsSync } = require('fs');
const path = require('path');
const home = require('os').homedir();
const program = require('commander');

const { signing } = require('../lib/sign');
const { APP_ID, VERSION } = require('../lib/constants');
const { fatal } = require('../lib/logger');

/**
 * Help
 */
program
  .name(
    `
$ marmot sign`,
  )
  .usage('')
  .on('--help', function() {
    console.log(`
Sign the artifact generated by the pack command at "./._temp/{APP_ID}.tar" into "./_packages/{APP_ID}_{VERSION}.amr", where APP_ID and VERSION are environmental variables.

`);
  });

/**
 * Parse
 */
program.parse(process.argv);

/**
 * entry
 * 1. check environmental variables
 * 2. invoke signing
 */
async function entry() {
  const privateKeyPath = path.join(home, '.marmot/rsa-key/private.pem');
  if (!existsSync(privateKeyPath)) {
    fatal(`Rsa key ${privateKeyPath.replace(home, '~')} does not exist.`);
  }
  const config = { version: VERSION, id: APP_ID };
  if (!config.id) {
    fatal('Missing environmental variable APP_ID');
  }
  if (!config.version) {
    fatal('Missing environmental variable VERSION');
  }

  try {
    await signing(config, privateKeyPath);
  } catch (e) {
    fatal('Sign offline-package failed: %s', e);
  }
}

entry();
