#!/usr/bin/env node

const path = require('path');
const childProcess = require('child_process');
const program = require('commander');

const { MARMOT_SERVER_URL, MARMOT_ACCESS_KEY_ID, MARMOT_ACCESS_KEY_SECRET } = require('../lib/constants');
const upload = require('../lib/upload');
const report = require('../lib/report');
const { UPLOAD_FILE_NAME } = require('../lib/constants');
const { log, success, fatal } = require('../lib/logger');
const { isExistedFile } = require('../lib/common/helper.js');

const cwd = process.cwd();

const fileName = UPLOAD_FILE_NAME;

/**
 * Help
 */
program
  .name(
    `
$ marmot upload`,
  )
  .usage('')
  .on('--help', function() {
    console.log(`
Archive the current directory as \`marmot-source.tgz\` and upload to Marmot.

Use the following environmental variables to configure the storage location and credentials:

| Key                      | Value                    |
| ------------------------ | ------------------------ |
| MARMOT_SERVER_URL        | Marmot server URL        |
| MARMOT_ACCESS_KEY_ID     | Marmot Access Key ID     |
| MARMOT_ACCESS_KEY_SECRET | Marmot Access Key Secret |

`);
  });

/**
 * Parse
 */
program.parse(process.argv);

// compress the file to .tgz, excluding node_modules folder
try {
  let command = `touch ${fileName}`;
  log('Executing ' + command);
  let stdout = childProcess.execSync(command);
  log(stdout.toString());

  command = `tar --exclude='./node_modules' --exclude='./.git' --exclude='./${fileName}' -czf ${fileName} .`;
  log('Executing ' + command);
  stdout = childProcess.execSync(command);
  log(stdout.toString());
} catch (e) {
  fatal(e);
}

const sourceFile = path.relative(cwd, fileName);

if (sourceFile.startsWith('.')) {
  fatal('${sourceFile} is not a valid relative path.');
}

if (!isExistedFile(sourceFile)) {
  fatal('${sourceFile} is not a file.');
}

if (!MARMOT_SERVER_URL) {
  fatal('Missing environmental variable MARMOT_SERVER_URL');
}

if (!MARMOT_ACCESS_KEY_ID) {
  fatal('Missing environmental variable MARMOT_ACCESS_KEY_ID');
}

if (!MARMOT_ACCESS_KEY_SECRET) {
  fatal('Missing environmental variable MARMOT_ACCESS_KEY_SECRET');
}

(async () => {
  const rsp = await upload(sourceFile);
  success('Upload success.');
  log(`Address: ${rsp.url}. Size: ${rsp.size}`);
  report(rsp.url, rsp.size, cwd);
})().catch(e => {
  fatal(e);
});
