'use strict';

const fs = require('fs');
const path = require('path');
const globby = require('globby');
const urllib = require('urllib');
const LCL = require('../common/last-commit-log');

const cwd = process.cwd();

let appName = '';
try {
  const pkg = require(path.join(cwd, 'package'));
  appName = pkg.name.replace(/@/g, '').replace(/\//g, '_');
} catch (error) {}

const _ = {};

_.appName = appName;

_.isExistedFile = file => {
  if (!fs.existsSync(file)) return false;
  if (fs.statSync(file).isFile()) return true;
  return false;
};

_.isExistedDir = dir => {
  if (!fs.existsSync(dir)) return false;
  if (fs.statSync(dir).isDirectory()) return true;
  return false;
};

const expandFile = async (sourcePath, ext = 'amr') => {
  const files = await globby(sourcePath, {
    expandDirectories: {
      extensions: [ext],
    },
  });
  if (!files.length) return '';
  return files[0];
};

_.getGitInfo = async function(directory) {
  const lcl = new LCL(directory);
  return await lcl.getLastCommit();
};

_.getPackageFileSize = async sourcePath => {
  let file = sourcePath;
  if (_.isExistedDir) {
    file = await expandFile(sourcePath);
  }
  if (!fs.existsSync(file)) return '';
  return fs.statSync(file).size;
};

_.postToGW = async function(server, content) {
  return urllib.request(`${server}/api/v2/gw`, {
    method: 'POST',
    data: content,
    contentType: 'json',
    dataType: 'json',
    followRedirect: true,
    timeout: [60 * 1000, 60 * 1000], // set connecting timeout to 5s and response timeout to 60s.
  });
};

_.request = urllib.request;

module.exports = _;
