'use strict';

const os = require('os');

const { appName } = require('./common/helper');

const RUNNER_TYPE_GITLAB = 'GITLAB';
const RUNNER_TYPE_BITBUCKET = 'BITBUCKET';
const RUNNER_TYPE_ACI = 'ACI';

const getEnv = () => {
  let runnerType = 'UNKNOWN';
  let buildNumber = '0';
  if (process.env.CI_SERVER_NAME === 'GitLab CI' || process.env.CI_SERVER_NAME === 'GitLab') {
    runnerType = RUNNER_TYPE_GITLAB;
    buildNumber = process.env.CI_BUILD_ID || process.env.CI_JOB_ID;
  } else if (process.env.BITBUCKET_BUILD_NUMBER) {
    runnerType = RUNNER_TYPE_BITBUCKET;
    buildNumber = process.env.BITBUCKET_BUILD_NUMBER;
  } else if (process.env.ACI_EXEC_ID) {
    runnerType = RUNNER_TYPE_ACI;
    buildNumber = process.env.ACI_EXEC_ID;
  }
  return {
    ci: {
      JOB_NAME: appName,
      BUILD_NUMBER: buildNumber,
      RUNNER_TYPE: runnerType,
    },
    platform: 'web',
    os: {
      nodeVersion: process.version,
      platform: os.platform(),
    },
  };
};

module.exports = {
  getEnv,
};
