const chalk = require('chalk');
const { format } = require('util');

const prefix = '[marmot-cli] ';

const loggerFactory = color => (...args) => {
  const msg = format.apply(format, args);
  console.log(chalk[color](prefix + msg));
};

/**
 * Log a `message` to the console.
 *
 * @param {String} message
 */
const log = loggerFactory('white');

/**
 * Log a success `message` to the console.
 *
 * @param {String} message
 */
const success = loggerFactory('cyan');
const warn = loggerFactory('yellow');
const error = loggerFactory('red');
/**
 * Log an error `message` to the console and exit.
 *
 * @param {String} message
 */

const fatal = (...args) => {
  error(...args);
  process.exit(1);
};

module.exports = {
  log,
  fatal,
  error,
  success,
  warn,
  loggerFactory,
};
