'use strict';

const { existsSync } = require('fs');
const path = require('path');
const home = require('os').homedir();
const rimraf = require('rimraf');
const gulp = require('gulp');
const tar = require('gulp-tar');

const TEMP_PATH = path.join(process.cwd(), '._temp');

const { log, success } = require('./logger');

/**
 * pack source files
 * 1. copy dist/* to ._temp/_tar/dist/*
 * 2. tar ._temp/_tar/dist/* to ._temp/_tar/dist/{APP_ID}.tar
 * 3. mv ._temp/_tar/dist/{APP_ID}.tar to ._temp/{APP_ID}.tar
 */
async function packFiles(config) {
  // avoid closure
  const DEFAULT_PATTERN = ['./dist/**/*'];
  log('Packing offline-package with config below...');
  log(config);

  if (existsSync(TEMP_PATH)) rimraf.sync(TEMP_PATH);

  let sourcePattern = DEFAULT_PATTERN;

  // parse include files
  if (Array.isArray(config.include) && config.include.length > 0) {
    sourcePattern = config.include;
  }

  // ignore config.ignores configuration
  if (Array.isArray(config.ignore)) {
    config.ignore.forEach(v => {
      sourcePattern.push('!' + v);
    });
  }
  const tarballName = config.id + '.tar';

  log('sourcePattern:', sourcePattern);

  gulp
    .src(sourcePattern)
    .on('end', () => {
      const tarProductPath = path.join(TEMP_PATH.replace(home, '~'), tarballName);
      success('Packed successfully at ' + tarProductPath);
    })
    .pipe(tar(tarballName))
    .pipe(gulp.dest(TEMP_PATH));
}

module.exports = {
  packFiles,
};
