#!/usr/bin/env node

const path = require('path');

const { postToGW, getGitInfo } = require('./common/helper');
const { MARMOT_SERVER_URL, PACKAGE_TYPE } = require('./constants');
const { getEnv } = require('./environment');
const { log, success, fatal, warn } = require('./logger');

const handleWebhookResponse = async (context, response) => {
  if (response.status === 200 && response.data.success) {
    log('Response: \n', JSON.stringify(response.data, null, 2));
    log('Request: \n', JSON.stringify(context, null, 2));
    success('Report ci result success.');
  } else {
    log('Response: \n', response);
    log('Request: \n', JSON.stringify(context, null, 2));
    fatal('Failed to report ci result.');
  }
};

module.exports = async function report(url, size, cwd) {
  // offline package version
  let version;
  let marmotConfig;
  try {
    const pkg = require(path.join(cwd, 'package'));
    version = pkg.version;
    marmotConfig = pkg.marmot;
  } catch (error) {
    warn('package.json not found.');
  }

  // mini program app.json
  let appJson;
  try {
    // there is a file called 'app.js', so we need to use 'app.json' instead of just 'app'
    appJson = require(path.join(cwd, 'app.json'));
  } catch (error) {}

  const context = {
    appJson,
    environment: await getEnv(),
    gitCommitInfo: await getGitInfo(),
    packages: [
      {
        version,
        type: PACKAGE_TYPE,
        path: url,
        size,
      },
    ],
    marmotConfig,
  };

  try {
    const response = await postToGW(MARMOT_SERVER_URL, context);
    await handleWebhookResponse(context, response);
  } catch (e) {
    log('Request:', JSON.stringify(context, null, 2));
    fatal('Failed to report ci result. %s', e);
  }
};
